@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -63,7 +63,7 @@ sub _add_prereqs_from_func_meta {
         }
     }
 
-    # from x.schema.{entity,element_entity} (cli script only)
+    # from x.schema.{entity,element_entity} & x.completion (cli script only)
     {
         last unless $is_cli;
         my $args = $meta->{args};
@@ -79,8 +79,19 @@ sub _add_prereqs_from_func_meta {
             if ($e) {
                 $self->_add_prereq("Perinci::Sub::ArgEntity::$e"=>0);
             }
+            $e = $arg_spec->{'x.completion'};
+            if ($e) {
+                die "x.completion must be an array" unless ref($e) eq 'ARRAY';
+                $self->_add_prereq("Perinci::Sub::XCompletion::$e->[0]"=>0);
+            }
+            $e = $arg_spec->{'x.element_completion'};
+            if ($e) {
+                die "x.element_completion must be an array" unless ref($e) eq 'ARRAY';
+                $self->_add_prereq("Perinci::Sub::XCompletion::$e->[0]"=>0);
+            }
         }
     }
+
 }
 
 sub munge_file {
@@ -160,7 +171,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-03-18.
+This document describes version 0.06 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -199,6 +210,12 @@ C<Perinci::Examples> (unless it's from the same distribution).
 For every entity mentioned in C<x.schema.entity> or C<x.schema.element_entity>
 in function metadata, will add a prereq to C<Perinci::Sub::ArgEntity::NAME>.
 
+=item *
+
+For every completion mentioned in C<x.completion> or C<x.element_completion> in
+function metadata (which have the value of C<[NAME, ARGS]>), will add a prereq
+to corresponding C<Perinci::Sub::XCompletion::NAME>.
+
 =back
 
 =for Pod::Coverage .+
